package com.example.myapplication.viewModels

import androidx.lifecycle.ViewModel
import androidx.lifecycle.ViewModelProvider
import androidx.lifecycle.ViewModelProvider.AndroidViewModelFactory.Companion.APPLICATION_KEY
import androidx.lifecycle.viewModelScope
import androidx.lifecycle.viewmodel.CreationExtras
import androidx.paging.PagingData
import androidx.paging.cachedIn
import com.example.myapplication.MyApp
import com.example.myapplication.database.entities.Product
import com.example.myapplication.database.repository.OfflineProductRepository
import com.example.myapplication.database.repository.ProductRepository
import kotlinx.coroutines.flow.Flow

class ProductViewModel(
    private val productRepository: ProductRepository
) : ViewModel() {
    companion object {
        val factory: ViewModelProvider.Factory = object : ViewModelProvider.Factory{
            override fun <T: ViewModel> create(
                modelClass: Class<T>,
                extras: CreationExtras
            ) : T {
                val db = (checkNotNull(extras[ViewModelProvider.AndroidViewModelFactory.APPLICATION_KEY]) as MyApp).db
                return ProductViewModel(OfflineProductRepository(db.productDao())) as T
            }
        }
    }

    fun getAll() : Flow<PagingData<Product>> {
        return productRepository.getAll().cachedIn(viewModelScope)
    }

    fun getById(id: Int) : Flow<Product> {
        return productRepository.getById(id)
    }

    fun getByCategory(cId: Int): Flow<PagingData<Product>> {
        return productRepository.getByCategory(cId).cachedIn(viewModelScope)
    }

    suspend fun insert(product: Product) {
        productRepository.insert(product)
    }
}