package com.example.myapplication.viewModels

import androidx.lifecycle.ViewModel
import androidx.lifecycle.ViewModelProvider
import androidx.lifecycle.viewmodel.CreationExtras
import com.example.myapplication.GlobalUser
import com.example.myapplication.MyApp
import com.example.myapplication.database.entities.User
import com.example.myapplication.database.entities.UserProductCart
import com.example.myapplication.database.entities.UserWithCartProduct
import com.example.myapplication.database.repository.OfflineUserRepository
import com.example.myapplication.database.repository.UserRepository
import kotlinx.coroutines.flow.Flow

class UserViewModel(
    private val userRepository: UserRepository
) : ViewModel() {
    companion object {
        val factory: ViewModelProvider.Factory = object : ViewModelProvider.Factory{
            override fun <T: ViewModel> create(
                modelClass: Class<T>,
                extras: CreationExtras
            ) : T {

                val db = (checkNotNull(extras[ViewModelProvider.AndroidViewModelFactory.APPLICATION_KEY]) as MyApp).db
                return UserViewModel(OfflineUserRepository(db.userDao())) as T
            }
        }
    }

    fun getUserId(): Int {
        return GlobalUser.getInstance().userId
    }

    fun setUserId(id: Int) {
        GlobalUser.getInstance().userId = id
    }

    fun getAll(): Flow<List<User>> {
        return userRepository.getAll()
    }
    fun getById(id: Int): Flow<User> {
        return userRepository.getById(id)
    }
    fun getByAuth(login: String, password: String): Flow<User?> {
        return userRepository.getByAuth(login, password)
    }
    suspend fun deleteCartProduct(userId: Int, productId: Int) {
        userRepository.deleteCartProduct(userId, productId)
    }
    fun getUserProductCartById(id: Int): Flow<UserWithCartProduct> {
        return userRepository.getUserProductCartById(id)
    }

    suspend fun insert(user: User) {
        userRepository.insert(user)
    }
    suspend fun addProductCart(userItem: UserProductCart) {
        userRepository.addProductCart(userItem)
    }

}